# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['llm_reflection']

package_data = \
{'': ['*']}

install_requires = \
['langchain-google-vertexai>=1.0.6,<2.0.0',
 'langchain-openai>=0.1.10,<0.2.0',
 'rich>=13.7.1,<14.0.0']

setup_kwargs = {
    'name': 'llm-reflection',
    'version': '0.1.0',
    'description': 'This system utilizes a large language model (LLM) and reflection',
    'long_description': '# LLM Reflection Library\n\nThis library provides a simple way to implement reflection in your LLM applications. Reflection is the process of having an LLM evaluate its own output and provide suggestions for improvement. This can be a powerful technique for improving the quality of LLM outputs.\n\nThis Library is based on [Translation Agent: Agentic translation using reflection workflow repository](https://github.com/andrewyng/translation-agent) and this article [Reflexion: Language Agents with Verbal Reinforcement Learning](https://arxiv.org/pdf/2303.11366)\n\n## Installation\n\n```bash\npip install llm-reflection-lib\n```\n\n## Usage\nThe library provides a LlmReflection class that you can use to interact with an LLM and implement reflection.\n\nHere is an example of how to use the library to translate a text from English to Spanish:\n\n```python\nfrom llm_reflection import LlmReflection\nfrom llm_reflection import GoogleParams\nfrom llm_reflection import PrompTemplate\nfrom rich.console import Console\n\nconsole = Console()\n\ndef example_translation():\n    source_lang = "english"\n    target_lang = "spanish"\n    source_text = """\n        OpenAI is American artificial intelligence (AI) research laboratory consisting of\n        the non-profit OpenAI Incorporated and its for-profit subsidiary corporation OpenAI\n        Limited Partnership. OpenAI conducts AI research with the declared intention of\n        promoting and developing a friendly AI. OpenAI systems run on an Azure-based supercomputing\n        platform from Microsoft.\n        The OpenAI API is powered by a diverse set of models with different capabilities and price points.\n    """\n\n    prompt = PrompTemplate(\n        person="You are an expert linguist, specializing in translation",\n        task=f"""This is an {source_lang} to {target_lang} translation, please provide the {target_lang} translation for this text.\n        Do not provide any explanations or text apart from the translation.\n        {source_lang}:{source_text}\n        {target_lang}:""",\n        output_format="Do not provide any explanations or text apart from the translation."\n    )\n\n    llm_reflection = LlmReflection(\n        GoogleParams(\n            model_name="gemini-1.5-flash",\n            temperature=0.8\n        ),\n        system_message="You are an expert linguist, specializing in translation"\n    )\n\n    translation = llm_reflection.generate_text(\n        prompt,\n        reflection_items=[\n            "accuracy (by correcting errors of addition, mistranslation, omission, or untranslated text)",\n            "fluency(by applying {target_lang} grammar, spelling and punctuation rules, and ensuring there are no unnecessary repetitions)",\n            "style(by ensuring the translations reflect the style of the source text and takes into account any cultural context)",\n            "terminology (by ensuring terminology use is consistent and reflects the source text domain; and by only ensuring you use equivalent idioms {target_lang}).",\n        ]\n    )\n\n    console.print("*"*10)\n    console.print(translation)\n\n```\n\nHere\'s the converted text in markdown:\n\n## This code will:\n\n* **Create a prompt template:** This defines the persona of the Large Language Model (LLM), the task to be performed, and any additional context.\n* **Create a LLMReflection object:** This object will be used to interact with the LLM.\n* **Generate text:** The `generate_text` method will generate text using the LLM and then provide reflection suggestions.\n\n## Reflection Items (These may or may not be used)\n\nThe `reflection_items` parameter in the `generate_text` method is a list of reflection points that the LLM should consider when evaluating its output. These reflection points should be specific and actionable.\n\nFor example, in the translation example above, the reflection points are:\n\n* **Accuracy:** The LLM should check for errors in the translation, such as mistranslations, omissions, or additions.\n* **Fluency:** The LLM should ensure that the translation is grammatically correct and flows naturally.\n* **Style:** The LLM should ensure that the translation reflects the style of the source text.\n* **Terminology:** The LLM should ensure that the translation uses appropriate terminology and idioms.\n\n## Supported LLMs\n\nThe library currently supports the following LLMs:\n\n* **Google Vertex AI:** You can use the `GoogleParams` class to configure the LLM.\n* **OpenAI:** You can use the `OpenAIParams` class to configure the LLM.\n\nMade with ❤ by  [jggomez](https://devhack.co).\n\n[![Twitter Badge](https://img.shields.io/badge/-@jggomezt-1ca0f1?style=flat-square&labelColor=1ca0f1&logo=twitter&logoColor=white&link=https://twitter.com/jggomezt)](https://twitter.com/jggomezt)\n[![Linkedin Badge](https://img.shields.io/badge/-jggomezt-blue?style=flat-square&logo=Linkedin&logoColor=white&link=https://www.linkedin.com/in/jggomezt/)](https://www.linkedin.com/in/jggomezt/)\n[![Medium Badge](https://img.shields.io/badge/-@jggomezt-03a57a?style=flat-square&labelColor=000000&logo=Medium&link=https://medium.com/@jggomezt)](https://medium.com/@jggomezt)\n\n## License\n\n    Copyright 2024 Juan Guillermo Gómez\n\n    Licensed under the Apache License, Version 2.0 (the "License");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an "AS IS" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.\n',
    'author': 'jggomez',
    'author_email': 'juan.gomez01@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
